<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="所属年度">
              <el-date-picker v-model="querys[0].value" type="year" value-format="yyyy" placeholder="请选择所属年度"
                style="width:100%;" />
              <!-- <el-input clearable placeholder="请输入所属目标" v-model="querys[0].value" /> -->
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="考评人">
              <el-input clearable placeholder="请输入考评人" v-model="querys[1].value" />
            </el-form-item>
          </el-col>
          <el-col :span="7">
            <el-form-item label="考评时间">
              <el-date-picker v-model="querys[2].value" clearable type="daterange" range-separator="至" style="width: 100%;"
                start-placeholder="开始日期" end-placeholder="结束日期" value-format="yyyy-MM-dd"></el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column fixed sortable prop="checkYear" label="所属年度" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="checkScore" label="目标考核综合得分" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed prop="assessor" label="考评人" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="assessorContent" label="考评结果描述" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed sortable prop="assessorDate" label="考评时间" show-overflow-tooltip>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <CmgtSaftyAppraisalFormDialog ref="formModal"></CmgtSaftyAppraisalFormDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import CmgtSaftyAppraisalApi from '@/views/Manage/saftyPlan/api/CmgtSaftyAppraisalApi'
import CmgtSaftyAppraisalFormDialog from '@/views/Manage/saftyPlan/components/CmgtSaftyAppraisalFormDialog'

export default {
  name: 'CmgtSaftyAppraisalManage',
  components: {
    CmgtSaftyAppraisalFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyCheck/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'check_year_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'assessor_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'assessor_date_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: []
    }
  },
  created() { },
  mounted() { },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      CmgtSaftyAppraisalApi.loadCmgtSaftyAppraisal(this.queryParam, res => {
        //console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
